## 标准测试项目

下面我们通过一张图看下标准的测试项目组织是怎么样的，如图：

![标准项目组织](./img/stand_project.png)

由图我们知道在AutoLink中项目由三层组织构成：

1. 项目层
2. 套件层
3. 用例层

## 如何定义顺序

请注意上图中套件名和用例名前面的数值序号，在AutoLink中通过在名称前添加数值序号来控制顺序，即：即时组织顺序，也是执行顺序